#!/usr/bin/env python
# -*- coding: utf-8 -*-

# This file is part of the
# Flask-NameExtension Project (https://github.com/juniors90/Flask-NameExtension/).
# Copyright (c) 2022, Ferreira Juan David
# License: MIT
# Full Text: https://github.com/juniors90/Flask-NameExtension/blob/master/LICENSE

# =============================================================================
# DOCS
# =============================================================================

"""Flask-NameExtension.

Implementation of NameExtension in Flask.
"""


# =============================================================================
# IMPORTS
# =============================================================================
import warnings

from flask import Blueprint, Markup, current_app, url_for

# docstr-coverage:excused `no one is reading this anyways`
def raise_helper(message):  # pragma: no cover
    raise RuntimeError(message)

def some_filters():
    return "Hello World!!"

class NameExtension(object):
    """Base extension class for different of NameExtension versions.
    .. versionadded:: 0.0.1
    """

    fomantic_version = None
    static_folder = None

    def __init__(self, app=None):
        if app is not None:
            self.init_app(app)

    def init_app(self, app):
        """Application factory."""

        # default settings
        app.config.setdefault("SOME_CONFIG_FOR_THIS_EXTENSION", False)

        if not hasattr(app, "extensions"):  # pragma: no cover
            app.extensions = {}
        
        app.extensions["extensionname"] = self
        
        blueprint = Blueprint(
            "extensionname",
            __name__,
            static_folder=f"static/{self.static_folder}",
            static_url_path=f"{app.static_url_path}",
            template_folder="templates",
        )

        app.register_blueprint(blueprint)

        app.jinja_env.globals["extensionname"] = self
        app.jinja_env.globals["some_filters"] = some_filters
        app.jinja_env.globals["warn"] = warnings.warn
        app.jinja_env.globals["raise"] = raise_helper
        app.jinja_env.add_extension("jinja2.ext.do")

        def hello(self, world):
            """The method example

            Parameters
            ----------
            world : str
                Some string.

            Return
            ------
            hello_world : str
                A string given by "Hello <world>".
            """
            hello_world = f"Hello {world}!!"
            return hello_world


#!/usr/bin/env python
# -*- coding: utf-8 -*-

# This file is part of the
#   Flask-NameExtension Project
#     (https://github.com/juniors90/Flask-Flask-NameExtension/).
# Copyright (c) 2022, Ferreira Juan David
# License: MIT
# Full Text:
#  https://github.com/juniors90/Flask-NameExtension/blob/master/LICENSE

# =====================================================================
# DOCS
# =====================================================================

"""This file is for distribute and install Flask-NameExtension"""

# ======================================================================
# IMPORTS
# ======================================================================

import os
import pathlib

from setuptools import setup  # noqa

# =============================================================================
# CONSTANTS
# =============================================================================

PATH = pathlib.Path(os.path.abspath(os.path.dirname(__file__)))


REQUIREMENTS = ["Flask>=2.0.1"]

with open(PATH / "flask_nameextension" / "__init__.py") as fp:
    for line in fp.readlines():
        if line.startswith("__version__ = "):
            VERSION = line.split("=", 1)[-1].replace('"', "").strip()
            break


with open("README.md") as fp:
    LONG_DESCRIPTION = fp.read()


source = "https://github.com/juniors90/Flask-NameExtension"
tracker = "https://github.com/juniors90/Flask-NameExtension/issues"
donate = "https://www.paypal.com/donate?hosted_button_id=LFAQ7E7TJ4HSY"
funding = "https://paypal.me/juniors90"


# =============================================================================
# FUNCTIONS
# =============================================================================

setup(
    name="Flask-NameExtension",
    version=VERSION,
    description="Flask Extension Template.",  # noqa: E501
    long_description=LONG_DESCRIPTION,
    long_description_content_type="text/markdown",
    author="Ferreira Juan David",
    author_email="juandavid9a0@gmail.com",
    url="https://github.com/juniors90/Flask-NameExtension",
    packages=["flask_nameextension"],
    include_package_data=True,
    platforms="any",
    license="The MIT License",
    install_requires=REQUIREMENTS,
    keywords=["Template", "Flask", "Framework"],
    project_urls={
        "Source": source,
        "Tracker": tracker,
        "Donate": donate,
        "Funding": funding,
    },
    classifiers=[
        "Development Status :: 4 - Beta",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
        "Programming Language :: Python",
        "Programming Language :: Python :: 3.8",
        "Topic :: Internet :: WWW/HTTP :: Dynamic Content",
        "Topic :: Software Development :: Libraries :: Python Modules",
    ],
)